==> activity-center-api-0.9.1.71-zbq1-20181114.130921-1-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/plant/PlantUserDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto.plant;

import java.io.Serializable;
import java.util.Date;

/**
 * [种红包]用户Dto
 *
 * @author zhangbaiqiang
 * @date 2018/11/11
 */
public class PlantUserDto implements Serializable {
    private static final long serialVersionUID = 4613581275376537304L;

    /**
     * 设备ID
     */
    private String deviceId;

    /**
     * 现金
     */
    private Long cash;

    /**
     * 金币
     */
    private Long coin;

    /**
     * 签到天数
     */
    private Integer signDays;

    /**
     * 上次签到时间
     */
    private Date lastSignTime;

    /**
     * 已解锁土地
     */
    private Integer unlockLand;

    public String getDeviceId() {
        return deviceId;
    }

    public PlantUserDto setDeviceId(String deviceId) {
        this.deviceId = deviceId;
        return this;
    }

    public Long getCash() {
        return cash;
    }

    public PlantUserDto setCash(Long cash) {
        this.cash = cash;
        return this;
    }

    public Long getCoin() {
        return coin;
    }

    public PlantUserDto setCoin(Long coin) {
        this.coin = coin;
        return this;
    }

    public Integer getSignDays() {
        return signDays;
    }

    public PlantUserDto setSignDays(Integer signDays) {
        this.signDays = signDays;
        return this;
    }

    public Date getLastSignTime() {
        return lastSignTime;
    }

    public PlantUserDto setLastSignTime(Date lastSignTime) {
        this.lastSignTime = lastSignTime;
        return this;
    }

    public Integer getUnlockLand() {
        return unlockLand;
    }

    public PlantUserDto setUnlockLand(Integer unlockLand) {
        this.unlockLand = unlockLand;
        return this;
    }
}

==> activity-center-api-0.9.1.88-zbq-20181221.092543-13-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/plant/PlantUserDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto.plant;

import java.io.Serializable;
import java.util.Date;

/**
 * [种红包]用户Dto
 *
 * @author zhangbaiqiang
 * @date 2018/11/11
 */
public class PlantUserDto implements Serializable {
    private static final long serialVersionUID = 4613581275376537304L;

    /**
     * 设备ID
     */
    private String deviceId;

    /**
     * 现金
     */
    private Long cash;

    /**
     * 金币
     */
    private Long coin;

    /**
     * 签到天数
     */
    private Integer signDays;

    /**
     * 上次签到时间
     */
    private Date lastSignTime;

    /**
     * 已解锁土地
     */
    private Integer unlockLand;

    /**
     * 播种次数
     */
    private Integer plantTimes;

    /**
     * 采摘次数
     */
    private Integer pickTimes;

    public String getDeviceId() {
        return deviceId;
    }

    public void setDeviceId(String deviceId) {
        this.deviceId = deviceId;
    }

    public Long getCash() {
        return cash;
    }

    public void setCash(Long cash) {
        this.cash = cash;
    }

    public Long getCoin() {
        return coin;
    }

    public void setCoin(Long coin) {
        this.coin = coin;
    }

    public Integer getSignDays() {
        return signDays;
    }

    public void setSignDays(Integer signDays) {
        this.signDays = signDays;
    }

    public Date getLastSignTime() {
        return lastSignTime;
    }

    public void setLastSignTime(Date lastSignTime) {
        this.lastSignTime = lastSignTime;
    }

    public Integer getUnlockLand() {
        return unlockLand;
    }

    public void setUnlockLand(Integer unlockLand) {
        this.unlockLand = unlockLand;
    }

    public Integer getPlantTimes() {
        return plantTimes;
    }

    public void setPlantTimes(Integer plantTimes) {
        this.plantTimes = plantTimes;
    }

    public Integer getPickTimes() {
        return pickTimes;
    }

    public void setPickTimes(Integer pickTimes) {
        this.pickTimes = pickTimes;
    }
}
